@@ -11,7 +11,7 @@
 #define MAX_LOOP (10000)
 #define MAX_THREADS (5)
 
-#define d(x)
+#define d (x)
 
 static const gchar *local_drivers[] = { "local" };
 static const gchar *local_providers[] = {
@@ -25,15 +25,27 @@ static CamelSession *session;
 static gint testid;
 
 static gpointer
-worker(gpointer d)
+worker (gpointer d)
 {
 	gint i;
 	CamelStore *store;
+	CamelService *service;
 	CamelFolder *folder;
 
-	for (i=0;i<MAX_LOOP;i++) {
-		store = camel_session_get_store(session, path, NULL);
-		folder = camel_store_get_folder(store, "testbox", CAMEL_STORE_FOLDER_CREATE, NULL);
+	for (i = 0; i < MAX_LOOP; i++) {
+		gchar *uid;
+
+		uid = g_strdup_printf ("test-uid-%d", i);
+		service = camel_session_add_service (
+			session, uid, path, CAMEL_PROVIDER_STORE, NULL);
+		g_free (uid);
+
+		check (CAMEL_IS_STORE (service));
+		store = CAMEL_STORE (service);
+
+		folder = camel_store_get_folder_sync (
+			store, "testbox",
+			CAMEL_STORE_FOLDER_CREATE, NULL, NULL);
 		if (testid == 0) {
 			g_object_unref (folder);
 			g_object_unref (store);
@@ -47,29 +59,30 @@ worker(gpointer d)
 }
 
 gint
-main(gint argc, gchar **argv)
+main (gint argc,
+      gchar **argv)
 {
 	gint i, j;
 	GThread *threads[MAX_THREADS];
 
-	camel_test_init(argc, argv);
-	camel_test_provider_init(1, local_drivers);
+	camel_test_init (argc, argv);
+	camel_test_provider_init (1, local_drivers);
 
 	/* clear out any camel-test data */
-	system("/bin/rm -rf /tmp/camel-test");
+	system ("/bin/rm -rf /tmp/camel-test");
 
 	session = camel_test_session_new ("/tmp/camel-test");
 
-	for (testid=0;testid<2;testid++) {
+	for (testid = 0; testid < 2; testid++) {
 		if (testid == 0)
-			camel_test_start("store and folder bag torture test, stacked references");
+			camel_test_start ("store and folder bag torture test, stacked references");
 		else
-			camel_test_start("store and folder bag torture test, unstacked references");
+			camel_test_start ("store and folder bag torture test, unstacked references");
 
 		for (j = 0; j < G_N_ELEMENTS (local_providers); j++) {
 
-			camel_test_push("provider %s", local_providers[j]);
-			path = g_strdup_printf("%s:///tmp/camel-test/%s", local_providers[j], local_providers[j]);
+			camel_test_push ("provider %s", local_providers[j]);
+			path = g_strdup_printf ("%s:///tmp/camel-test/%s", local_providers[j], local_providers[j]);
 
 			for (i = 0; i < MAX_THREADS; i++) {
 				GError *error = NULL;
@@ -86,12 +99,12 @@ main(gint argc, gchar **argv)
 					g_thread_join (threads[i]);
 			}
 
-			test_free(path);
+			test_free (path);
 
-			camel_test_pull();
+			camel_test_pull ();
 		}
 
-		camel_test_end();
+		camel_test_end ();
 	}
 
 	g_object_unref (session);
