@@ -6,7 +6,8 @@
 #include "client-test-utils.h"
 
 gint
-main (gint argc, gchar **argv)
+main (gint argc,
+      gchar **argv)
 {
 	EBookClient *book_client = NULL;
 	EContact *contact = NULL;
